<?php

if(!function_exists('malmo_elated_search_options_map')) {

    function malmo_elated_search_options_map() {

        malmo_elated_add_admin_page(
            array(
                'slug'  => '_search_page',
                'title' => esc_html__('Search', 'malmo'),
                'icon'  => 'fa fa-search'
            )
        );

        $search_panel = malmo_elated_add_admin_panel(
            array(
                'title' => esc_html__('Search', 'malmo'),
                'name'  => 'search',
                'page'  => '_search_page'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'select',
                'name'          => 'search_type',
                'default_value' => 'search-slides-from-header-bottom',
                'label'         => esc_html__('Select Search Type', 'malmo'),
                'description'   => esc_html__("Choose a type of Elated search bar (Note: Slide From Header Bottom search type doesn't work with transparent header)", 'malmo'),
                'options'       => array(
                    'search-slides-from-header-bottom' => esc_html__('Slide From Header Bottom', 'malmo'),
                    'search-covers-header'             => esc_html__('Search Covers Header', 'malmo'),
                    'fullscreen-search'                => esc_html__('Fullscreen Search', 'malmo'),
                    'search-slides-from-window-top'    => esc_html__('Slide from Window Top', 'malmo'),
                    'search-dropdown'                  => esc_html__('Search Dropdown', 'malmo')
                ),
                'args'          => array(
                    'dependence' => true,
                    'hide'       => array(
                        'search-slides-from-header-bottom' => '#eltd_search_animation_container',
                        'search-covers-header'             => '#eltd_search_height_container, #eltd_search_animation_container',
                        'fullscreen-search'                => '#eltd_search_height_container',
                        'search-slides-from-window-top'    => '#eltd_search_height_container, #eltd_search_animation_container'
                    ),
                    'show'       => array(
                        'search-slides-from-header-bottom' => '#eltd_search_height_container',
                        'search-covers-header'             => '',
                        'fullscreen-search'                => '#eltd_search_animation_container',
                        'search-slides-from-window-top'    => ''
                    )
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'select',
                'name'          => 'search_icon_pack',
                'default_value' => 'font_awesome',
                'label'         => esc_html__('Search Icon Pack', 'malmo'),
                'description'   => esc_html__('Choose icon pack for search icon', 'malmo'),
                'options'       => malmo_elated_icon_collections()->getIconCollectionsExclude(array(
                    'linea_icons',
                    'simple_line_icons',
                    'dripicons'
                ))
            )
        );

        $search_height_container = malmo_elated_add_admin_container(
            array(
                'parent'          => $search_panel,
                'name'            => 'search_height_container',
                'hidden_property' => 'search_type',
                'hidden_value'    => '',
                'hidden_values'   => array(
                    'search-covers-header',
                    'fullscreen-search',
                    'search-slides-from-window-top'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_height_container,
                'type'          => 'text',
                'name'          => 'search_height',
                'default_value' => '',
                'label'         => esc_html__('Search bar height', 'malmo'),
                'description'   => esc_html__('Set search bar height', 'malmo'),
                'args'          => array(
                    'col_width' => 3,
                    'suffix'    => 'px'
                )
            )
        );

        $search_animation_container = malmo_elated_add_admin_container(
            array(
                'parent'          => $search_panel,
                'name'            => 'search_animation_container',
                'hidden_property' => 'search_type',
                'hidden_value'    => '',
                'hidden_values'   => array(
                    'search-covers-header',
                    'search-slides-from-header-bottom',
                    'search-slides-from-window-top'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'yesno',
                'name'          => 'search_in_grid',
                'default_value' => 'yes',
                'label'         => esc_html__('Search area in grid', 'malmo'),
                'description'   => esc_html__('Set search area to be in grid', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(array(
            'name'        => 'fullscreen_search_background_color',
            'type'        => 'color',
            'parent'      => $search_animation_container,
            'label'       => esc_html__('Full Screen Search Background Color', 'malmo'),
            'description' => esc_html__('Choose full screen search background color', 'malmo')
        ));

        malmo_elated_add_admin_section_title(
            array(
                'parent' => $search_panel,
                'name'   => 'initial_header_icon_title',
                'title'  => esc_html__('Initial Search Icon in Header', 'malmo')
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'text',
                'name'          => 'header_search_icon_size',
                'default_value' => '',
                'label'         => esc_html__('Icon Size', 'malmo'),
                'description'   => esc_html__('Set size for icon', 'malmo'),
                'args'          => array(
                    'col_width' => 3,
                    'suffix'    => 'px'
                )
            )
        );

        $search_icon_color_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Icon Colors', 'malmo'),
                'description' => esc_html__('Define color style for icon', 'malmo'),
                'name'        => 'search_icon_color_group'
            )
        );

        $search_icon_color_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_icon_color_group,
                'name'   => 'search_icon_color_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row,
                'type'   => 'colorsimple',
                'name'   => 'header_search_icon_color',
                'label'  => esc_html__('Color', 'malmo')
            )
        );
        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row,
                'type'   => 'colorsimple',
                'name'   => 'header_search_icon_hover_color',
                'label'  => esc_html__('Hover Color', 'malmo')
            )
        );
        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row,
                'type'   => 'colorsimple',
                'name'   => 'header_light_search_icon_color',
                'label'  => esc_html__('Light Header Icon Color', 'malmo')
            )
        );
        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row,
                'type'   => 'colorsimple',
                'name'   => 'header_light_search_icon_hover_color',
                'label'  => esc_html__('Light Header Icon Hover Color', 'malmo')
            )
        );

        $search_icon_color_row2 = malmo_elated_add_admin_row(
            array(
                'parent' => $search_icon_color_group,
                'name'   => 'search_icon_color_row2',
                'next'   => true
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row2,
                'type'   => 'colorsimple',
                'name'   => 'header_dark_search_icon_color',
                'label'  => esc_html__('Dark Header Icon Color', 'malmo')
            )
        );
        malmo_elated_add_admin_field(
            array(
                'parent' => $search_icon_color_row2,
                'type'   => 'colorsimple',
                'name'   => 'header_dark_search_icon_hover_color',
                'label'  => esc_html__('Dark Header Icon Hover Color', 'malmo')
            )
        );


        $search_icon_background_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Icon Background Style', 'malmo'),
                'description' => esc_html__('Define background style for icon', 'malmo'),
                'name'        => 'search_icon_background_group'
            )
        );

        $search_icon_background_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_icon_background_group,
                'name'   => 'search_icon_background_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_background_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_background_color',
                'default_value' => '',
                'label'         => esc_html__('Background Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_background_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_background_hover_color',
                'default_value' => '',
                'label'         => esc_html__('Background Hover Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'yesno',
                'name'          => 'enable_search_icon_text',
                'default_value' => 'no',
                'label'         => esc_html__('Enable Search Icon Text', 'malmo'),
                'description'   => esc_html__("Enable this option to show 'Search' text next to search icon in header", 'malmo'),
                'args'          => array(
                    'dependence'             => true,
                    'dependence_hide_on_yes' => '',
                    'dependence_show_on_yes' => '#eltd_enable_search_icon_text_container'
                )
            )
        );

        $enable_search_icon_text_container = malmo_elated_add_admin_container(
            array(
                'parent'          => $search_panel,
                'name'            => 'enable_search_icon_text_container',
                'hidden_property' => 'enable_search_icon_text',
                'hidden_value'    => 'no'
            )
        );

        $enable_search_icon_text_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $enable_search_icon_text_container,
                'title'       => esc_html__('Search Icon Text', 'malmo'),
                'name'        => 'enable_search_icon_text_group',
                'description' => esc_html__('Define Style for Search Icon Text', 'malmo')
            )
        );

        $enable_search_icon_text_row = malmo_elated_add_admin_row(
            array(
                'parent' => $enable_search_icon_text_group,
                'name'   => 'enable_search_icon_text_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_text_color',
                'label'         => esc_html__('Text Color', 'malmo'),
                'default_value' => ''
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_text_color_hover',
                'label'         => esc_html__('Text Hover Color', 'malmo'),
                'default_value' => ''
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row,
                'type'          => 'textsimple',
                'name'          => 'search_icon_text_fontsize',
                'label'         => esc_html__('Font Size', 'malmo'),
                'default_value' => '',
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row,
                'type'          => 'textsimple',
                'name'          => 'search_icon_text_lineheight',
                'label'         => esc_html__('Line Height', 'malmo'),
                'default_value' => '',
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $enable_search_icon_text_row2 = malmo_elated_add_admin_row(
            array(
                'parent' => $enable_search_icon_text_group,
                'name'   => 'enable_search_icon_text_row2',
                'next'   => true
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_icon_text_texttransform',
                'label'         => esc_html__('Text Transform', 'malmo'),
                'default_value' => '',
                'options'       => malmo_elated_get_text_transform_array()
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row2,
                'type'          => 'fontsimple',
                'name'          => 'search_icon_text_google_fonts',
                'label'         => esc_html__('Font Family', 'malmo'),
                'default_value' => '-1',
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_icon_text_fontstyle',
                'label'         => esc_html__('Font Style', 'malmo'),
                'default_value' => '',
                'options'       => malmo_elated_get_font_style_array(),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_icon_text_fontweight',
                'label'         => esc_html__('Font Weight', 'malmo'),
                'default_value' => '',
                'options'       => malmo_elated_get_font_weight_array(),
            )
        );

        $enable_search_icon_text_row3 = malmo_elated_add_admin_row(
            array(
                'parent' => $enable_search_icon_text_group,
                'name'   => 'enable_search_icon_text_row3',
                'next'   => true
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $enable_search_icon_text_row3,
                'type'          => 'textsimple',
                'name'          => 'search_icon_text_letterspacing',
                'label'         => esc_html__('Letter Spacing', 'malmo'),
                'default_value' => '',
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $search_icon_spacing_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Icon Spacing', 'malmo'),
                'description' => esc_html__('Define padding and margins for Search icon', 'malmo'),
                'name'        => 'search_icon_spacing_group'
            )
        );

        $search_icon_spacing_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_icon_spacing_group,
                'name'   => 'search_icon_spacing_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_spacing_row,
                'type'          => 'textsimple',
                'name'          => 'search_padding_left',
                'default_value' => '',
                'label'         => esc_html__('Padding Left', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_spacing_row,
                'type'          => 'textsimple',
                'name'          => 'search_padding_right',
                'default_value' => '',
                'label'         => esc_html__('Padding Right', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_spacing_row,
                'type'          => 'textsimple',
                'name'          => 'search_margin_left',
                'default_value' => '',
                'label'         => esc_html__('Margin Left', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_spacing_row,
                'type'          => 'textsimple',
                'name'          => 'search_margin_right',
                'default_value' => '',
                'label'         => esc_html__('Margin Right', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_section_title(
            array(
                'parent' => $search_panel,
                'name'   => 'search_form_title',
                'title'  => esc_html__('Search Bar', 'malmo')
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_panel,
                'type'          => 'color',
                'name'          => 'search_background_color',
                'default_value' => '',
                'label'         => esc_html__('Background Color', 'malmo'),
                'description'   => esc_html__('Choose a background color for Elated search bar', 'malmo')
            )
        );

        $search_input_text_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Search Input Text', 'malmo'),
                'description' => esc_html__('Define style for search text', 'malmo'),
                'name'        => 'search_input_text_group'
            )
        );

        $search_input_text_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_input_text_group,
                'name'   => 'search_input_text_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row,
                'type'          => 'colorsimple',
                'name'          => 'search_text_color',
                'default_value' => '',
                'label'         => esc_html__('Text Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row,
                'type'          => 'colorsimple',
                'name'          => 'search_text_disabled_color',
                'default_value' => '',
                'label'         => esc_html__('Disabled Text Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row,
                'type'          => 'textsimple',
                'name'          => 'search_text_fontsize',
                'default_value' => '',
                'label'         => esc_html__('Font Size', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row,
                'type'          => 'selectblanksimple',
                'name'          => 'search_text_texttransform',
                'default_value' => '',
                'label'         => esc_html__('Text Transform', 'malmo'),
                'options'       => malmo_elated_get_text_transform_array()
            )
        );

        $search_input_text_row2 = malmo_elated_add_admin_row(
            array(
                'parent' => $search_input_text_group,
                'name'   => 'search_input_text_row2'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row2,
                'type'          => 'fontsimple',
                'name'          => 'search_text_google_fonts',
                'default_value' => '-1',
                'label'         => esc_html__('Font Family', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_text_fontstyle',
                'default_value' => '',
                'label'         => esc_html__('Font Style', 'malmo'),
                'options'       => malmo_elated_get_font_style_array(),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_text_fontweight',
                'default_value' => '',
                'label'         => esc_html__('Font Weight', 'malmo'),
                'options'       => malmo_elated_get_font_weight_array()
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_input_text_row2,
                'type'          => 'textsimple',
                'name'          => 'search_text_letterspacing',
                'default_value' => '',
                'label'         => esc_html__('Letter Spacing', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $search_label_text_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Search Label Text', 'malmo'),
                'description' => esc_html__('Define style for search label text', 'malmo'),
                'name'        => 'search_label_text_group'
            )
        );

        $search_label_text_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_label_text_group,
                'name'   => 'search_label_text_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row,
                'type'          => 'colorsimple',
                'name'          => 'search_label_text_color',
                'default_value' => '',
                'label'         => esc_html__('Text Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row,
                'type'          => 'textsimple',
                'name'          => 'search_label_text_fontsize',
                'default_value' => '',
                'label'         => esc_html__('Font Size', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row,
                'type'          => 'selectblanksimple',
                'name'          => 'search_label_text_texttransform',
                'default_value' => '',
                'label'         => esc_html__('Text Transform', 'malmo'),
                'options'       => malmo_elated_get_text_transform_array()
            )
        );

        $search_label_text_row2 = malmo_elated_add_admin_row(
            array(
                'parent' => $search_label_text_group,
                'name'   => 'search_label_text_row2',
                'next'   => true
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row2,
                'type'          => 'fontsimple',
                'name'          => 'search_label_text_google_fonts',
                'default_value' => '-1',
                'label'         => esc_html__('Font Family', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_label_text_fontstyle',
                'default_value' => '',
                'label'         => esc_html__('Font Style', 'malmo'),
                'options'       => malmo_elated_get_font_style_array()
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row2,
                'type'          => 'selectblanksimple',
                'name'          => 'search_label_text_fontweight',
                'default_value' => '',
                'label'         => esc_html__('Font Weight', 'malmo'),
                'options'       => malmo_elated_get_font_weight_array()
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_label_text_row2,
                'type'          => 'textsimple',
                'name'          => 'search_label_text_letterspacing',
                'default_value' => '',
                'label'         => esc_html__('Letter Spacing', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $search_icon_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Search Icon', 'malmo'),
                'description' => esc_html__('Define style for search icon', 'malmo'),
                'name'        => 'search_icon_group'
            )
        );

        $search_icon_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_icon_group,
                'name'   => 'search_icon_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_color',
                'default_value' => '',
                'label'         => esc_html__('Icon Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_hover_color',
                'default_value' => '',
                'label'         => esc_html__('Icon Hover Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_row,
                'type'          => 'colorsimple',
                'name'          => 'search_icon_disabled_color',
                'default_value' => '',
                'label'         => esc_html__('Icon Disabled Color', 'malmo'),
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_icon_row,
                'type'          => 'textsimple',
                'name'          => 'search_icon_size',
                'default_value' => '',
                'label'         => esc_html__('Icon Size', 'malmo'),
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $search_close_icon_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Search Close', 'malmo'),
                'description' => esc_html__('Define style for search close icon', 'malmo'),
                'name'        => 'search_close_icon_group'
            )
        );

        $search_close_icon_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_close_icon_group,
                'name'   => 'search_icon_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_close_icon_row,
                'type'          => 'colorsimple',
                'name'          => 'search_close_color',
                'label'         => esc_html__('Icon Color', 'malmo'),
                'default_value' => ''
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_close_icon_row,
                'type'          => 'colorsimple',
                'name'          => 'search_close_hover_color',
                'label'         => esc_html__('Icon Hover Color', 'malmo'),
                'default_value' => ''
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_close_icon_row,
                'type'          => 'textsimple',
                'name'          => 'search_close_size',
                'label'         => esc_html__('Icon Size', 'malmo'),
                'default_value' => '',
                'args'          => array(
                    'suffix' => 'px'
                )
            )
        );

        $search_bottom_border_group = malmo_elated_add_admin_group(
            array(
                'parent'      => $search_panel,
                'title'       => esc_html__('Search Bottom Border', 'malmo'),
                'description' => esc_html__('Define style for Search text input bottom border (for Fullscreen search type)', 'malmo'),
                'name'        => 'search_bottom_border_group'
            )
        );

        $search_bottom_border_row = malmo_elated_add_admin_row(
            array(
                'parent' => $search_bottom_border_group,
                'name'   => 'search_icon_row'
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_bottom_border_row,
                'type'          => 'colorsimple',
                'name'          => 'search_border_color',
                'label'         => esc_html__('Border Color', 'malmo'),
                'default_value' => ''
            )
        );

        malmo_elated_add_admin_field(
            array(
                'parent'        => $search_bottom_border_row,
                'type'          => 'colorsimple',
                'name'          => 'search_border_focus_color',
                'label'         => esc_html__('Border Focus Color', 'malmo'),
                'default_value' => ''
            )
        );

    }

    add_action('malmo_elated_options_map', 'malmo_elated_search_options_map', 7);

}